@@ -286,6 +286,7 @@ class ConnectionPageBin(Adw.Bin):
             self.logger.warning("no interface")
             return
 
+        self.set_connected_button_sensitivity(True)
         notification._withdraw_lost_connection_notification()
 
         self.database = message_storage.MessageStorage(self.interface)
@@ -293,8 +294,6 @@ class ConnectionPageBin(Adw.Bin):
         win.window_toast_overlay.add_toast(Adw.Toast(title="Connected"))
         win.nearby_nodes_page_bin.populate_all_nodes(self.interface)
         win.channels_page_bin.populate_all_channels_and_dms(self.interface)
-        self.set_connected_button_sensitivity(True)
-
         node = self.interface.getNode('^local')
         # check if node is UNSET, which is 0
 
@@ -626,7 +625,7 @@ class ConnectionPageBin(Adw.Bin):
         node = self.interface.getNode('^local')
         node.localConfig.lora.region = self.region_selection.get_selected()
         node.writeConfig("lora")
-        win.window_toast_overlay.add_toast(Adw.Toast(title="Set Region"))
+        win.window_toast_overlay.add_toast(Adw.Toast(title="Region Successfully Set"))
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
