@@ -71,6 +71,9 @@ class DeviceConfigurationPageBin(Adw.Bin):
     wifi_password_entry = Gtk.Template.Child()
     wifi_enabled_switch = Gtk.Template.Child()
 
+    telemetry_settings_expander_row = Gtk.Template.Child()
+    power_metrics_enabled_switch = Gtk.Template.Child()
+
     dhcp_enabled_switch = Gtk.Template.Child()
     ipv4_config_ip = Gtk.Template.Child()
     ipv4_config_gateway = Gtk.Template.Child()
@@ -91,6 +94,7 @@ class DeviceConfigurationPageBin(Adw.Bin):
             self.node_name_expander_row.set_expanded(False)
             self.channel_expander_row.set_expanded(False)
             self.bluetooth_settings_expander_row.set_expanded(False)
+            self.telemetry_settings_expander_row.set_expanded(False)
 
         self._clear_channel_entries()
         self.long_name_entry.set_text(win.nearby_nodes_page_bin.own_node.longName)
@@ -145,6 +149,8 @@ class DeviceConfigurationPageBin(Adw.Bin):
 
         self.role_selection.set_selected(node.localConfig.device.role)
 
+        self.power_metrics_enabled_switch.set_active(node.moduleConfig.telemetry.power_measurement_enabled)
+
     def set_connected_button_sensitivity(self, sensitivity):
         not_sensitivity = not sensitivity
         #Set sensitive when connected
@@ -464,6 +470,24 @@ class DeviceConfigurationPageBin(Adw.Bin):
 
         node.writeConfig("bluetooth")
 
+    @Gtk.Template.Callback()
+    def _apply_telemetry_settings_clicked_cb(self, button):
+        app = Gtk.Application.get_default()
+        win = Gtk.Application.get_active_window(app)
+        node = self.interface.getNode('^local')
+
+        enable_power_metrics = self.power_metrics_enabled_switch.get_active()
+
+        self.logger.debug("Power Metrics Enabled: " + str(enable_power_metrics))
+
+        node.moduleConfig.telemetry.power_measurement_enabled = enable_power_metrics
+
+        self.logger.debug("Applying Telemetry Settings")
+        win.window_toast_overlay.add_toast(Adw.Toast(title="Telemetry Settings Applied"))
+        GLib.timeout_add(self.disconnection_timeout, self.disconnection_event_cb)
+
+        node.writeConfig("telemetry")
+
     @Gtk.Template.Callback()
     def _bluetooth_enabled_switch_row_notify_active_cb(self, switch_row, user):
         app = Gtk.Application.get_default()
