@@ -96,11 +96,14 @@ class NodeRow(Adw.ExpanderRow):
     __gtype_name__ = 'NodeRow'
 
     device_info = Gtk.Template.Child()
+    device_powerinfo = Gtk.Template.Child()
     other_stats = Gtk.Template.Child()
     popover = Gtk.Template.Child()
     position = Gtk.Template.Child()
     short_name_label = Gtk.Template.Child()
     snr_label = Gtk.Template.Child()
+    vlt_label = Gtk.Template.Child()
+    cur_label = Gtk.Template.Child()
     uptime = Gtk.Template.Child()
     public_key = Gtk.Template.Child()
     favorite_button = Gtk.Template.Child()
@@ -109,6 +112,7 @@ class NodeRow(Adw.ExpanderRow):
     num = 0
     devicePositionPresent = False
     deviceMetricPresent = False
+    devicePowerMetricPresent = False
     isLicensed = False
     own_node = False
     favorited = False
@@ -123,6 +127,7 @@ class NodeRow(Adw.ExpanderRow):
         self.set_subtitle("")
         self.other_stats.set_visible(False)
         self.device_info.set_visible(False)
+        self.device_powerinfo.set_visible(False)
         self.position.set_visible(False)
         self.public_key.set_visible(False)
 
@@ -161,8 +166,9 @@ class NodeRow(Adw.ExpanderRow):
         if hasattr(self, 'lastHeard') and self.lastHeard > 0:
             self.set_subtitle("Last Heard: " + utils.getTimeAgoDate(self.lastHeard))
 
-        # initializing string
+        # initializing strings
         other_stats_string = ""
+        hop_string = ""
 
         if hasattr(self, 'uptimeSeconds'):
             other_stats_string = other_stats_string + "Uptime: " + utils.getTimeAgoSec(self.uptimeSeconds) + ", "
@@ -175,20 +181,32 @@ class NodeRow(Adw.ExpanderRow):
 
         self.other_stats.set_subtitle(other_stats_string)
 
-        if hasattr(self, 'snr') and hasattr(self, 'rssi') :
+        # Generate a set of circles to visualize the hopcount
+        if hasattr(self, 'hopsAway'):
+            hop_string  = "\n\u25CF-" + "\u25CB-" * self.hopsAway + "\u25CF"
+        elif self.own_node:
+            hop_string = "\n\u25CF"
+        else:
+            hop_string = "\n\u25CF" + "-" + "\u25CF"
+
         # Set the SNR label with the SNR value and signal strength bars based on https://sensing-labs.com/f-a-q/a-good-radio-level/
+        if hasattr(self, 'snr') and hasattr(self, 'rssi'):
             if self.snr >= -7 and self.rssi >= -115:
                 signal_strength_bars = "████"  # 4 filled bars (strong signal)
             elif self.snr >= -7 and self.rssi >= -126 or self.snr >= -15 and self.rssi >= -115 or self.snr >= -15 and self.rssi >= -126 and self.rssi >= -115 + (self.snr + 15) * -1 * (115 - 126) / (7 - 15):
                 signal_strength_bars = "███░"  # 3 filled bars (moderate signal)
-            elif self.snr >= -17.5 and self.rssi >= -130 and self.snr >= -17.5 and self.rssi > -130 + (self.snr + 15) * -5 / 2.5: 
+            elif self.snr >= -17.5 and self.rssi >= -130 and self.snr >= -17.5 and self.rssi > -130 + (self.snr + 15) * -5 / 2.5:
                 signal_strength_bars = "██░░"  # 2 filled bars (weak signal)
             elif self.snr >= -17.5 and self.rssi >= -130 and self.rssi <= -130 + (self.snr + 15) * -5 / 2.5:
                 signal_strength_bars = "█░░░"  # 1 filled bar (very weak signal)
             else:
                 signal_strength_bars = "░░░░"  # 1 filled bar (even weaker signal)
 
-            self.snr_label.set_label("SNR: " + format(self.snr, '.2f') + "  " + signal_strength_bars)
+            self.snr_label.set_label("SNR: " + format(self.snr, '.2f') + "  " + signal_strength_bars + hop_string)
+        else:
+            self.snr_label.set_label(hop_string)
+
+        self.snr_label.set_justify(Gtk.Justification.RIGHT)
 
 
         if not self.deviceMetricPresent:
@@ -210,6 +228,24 @@ class NodeRow(Adw.ExpanderRow):
         elif hasattr(self, 'airUtilTx'):
             self.device_info.set_subtitle("Air Util Tx: " + format(self.airUtilTx, '.2f'))
 
+        if not self.devicePowerMetricPresent:
+            self.device_powerinfo.set_visible(False)
+        else:
+            self.device_powerinfo.set_visible(True)
+
+        if hasattr(self, 'ch1Voltage') and hasattr(self, 'ch1Current'):
+            if hasattr(self, 'ch2Voltage') and hasattr(self, 'ch2Current'):
+                if hasattr(self, 'ch3Voltage') and hasattr(self, 'ch3Current'):
+                    self.vlt_label.set_label("Ch1 Voltage: {:>10.2f}\nCh2 Voltage: {:>10.2f}\nCh3 Voltage: {:>10.2f}".format(self.ch1Voltage, self.ch2Voltage, self.ch3Voltage))
+                    self.cur_label.set_label("|  Ch1 Current: {:>10.2f}\n|  Ch2 Current: {:>10.2f}\n|  Ch3 Current: {:>10.2f}".format(self.ch1Current, self.ch2Current, self.ch3Current))
+                else:
+                    self.vlt_label.set_label("Ch1 Voltage: {:>10.2f}\nCh2 Voltage: {:>10.2f}".format(self.ch1Voltage, self.ch2Voltage))
+                    self.cur_label.set_label("|  Ch1 Current: {:>10.2f}\n|  Ch2 Current: {:>10.2f}".format(self.ch1Current, self.ch2Current))
+            else:
+                self.vlt_label.set_label("Ch1 Voltage: {:>10.2f}".format(self.ch1Voltage))
+                self.cur_label.set_label("|  Ch1 Current: {:>10.2f}".format(self.ch1Current))
+
+
         if not self.devicePositionPresent:
             self.position.set_visible(False)
         else:
@@ -238,7 +274,7 @@ class NodeRow(Adw.ExpanderRow):
             self.position.set_visible(False)
 
         if hasattr(self, 'altitude'):
-            self.position.set_subtitle("Altitude: " + str(self.altitude))
+            self.position.set_subtitle("Altitude: " + str(self.altitude) + " m (" + "{:.0f}".format(self.altitude*3.28084) + " ft)")
 
         if hasattr(self, 'publicKey') and self.publicKey != "MA==":
             self.public_key.set_visible(True)
@@ -276,7 +312,7 @@ class NodeRow(Adw.ExpanderRow):
             self.marker.set_location(self.latitude, self.longitude)
             if self.own_node:
                 win.maps_page_bin.goto_map_first_load(self.latitude, self.longitude)
-                win.maps_page_bin.load_own_node_lat_long(self.latitude, self.longitude)
+                win.maps_page_bin.load_own_node_lat_long(self.latitude, self.longitude, self.altitude)
             else:
                 win.maps_page_bin.define_longitude_last_seen(self.longitude)
                 win.maps_page_bin.define_latitude_last_seen(self.latitude)
@@ -330,6 +366,28 @@ class NodeRow(Adw.ExpanderRow):
         else:
             self.deviceMetricPresent = False
 
+        if node.get('powerMetrics'):
+            self.devicePowerMetricPresent = True
+            if node.get("powerMetrics", {}).get("ch1Voltage"):
+                self.ch1Voltage = node["powerMetrics"]["ch1Voltage"]
+
+            if node.get("powerMetrics", {}).get("ch1Current"):
+                self.ch1Current = node["powerMetrics"]["ch1Current"]
+
+            if node.get("powerMetrics", {}).get("ch2Voltage"):
+                self.ch2Voltage = node["powerMetrics"]["ch2Voltage"]
+
+            if node.get("powerMetrics", {}).get("ch2Current"):
+                self.ch2Current = node["powerMetrics"]["ch2Current"]
+
+            if node.get("powerMetrics", {}).get("ch3Voltage"):
+                self.ch3Voltage = node["powerMetrics"]["ch3Voltage"]
+
+            if node.get("powerMetrics", {}).get("ch3Current"):
+                self.ch3Current = node["powerMetrics"]["ch3Current"]
+        else:
+            self.devicePowerMetricPresent = False
+
         if node.get('position'):
             self.devicePositionPresent = True
             if node.get("position", {}).get("time"):
@@ -386,7 +444,7 @@ class NodeRow(Adw.ExpanderRow):
                 if 'hopsAway' in packet:
                     self.hopsAway = packet["hopsAway"]
 
-                win.connection_page_bin.database.update_direct_message(self)
+                win.connection_page_bin.database.update_direct_message_chat(self)
                 if self.favorited:
                     win.connection_page_bin.database.update_favorite_node(self)
 
@@ -414,27 +472,23 @@ class NodeRow(Adw.ExpanderRow):
                 elif 'rxTime' in packet:
                     self.position_time = packet["rxTime"]
 
-            elif packet['decoded'].get('portnum') == 'TELEMETRY_APP':
-                self.deviceMetricPresent = True
-                telemetry = packet['decoded'].get('telemetry', {})
-
+            elif packet.get('decoded', {}).get('portnum') == 'TELEMETRY_APP':
+                telemetry = packet.get('decoded', {}).get('telemetry', {})
                 device_metrics = telemetry.get('deviceMetrics', {})
+                power_metrics = telemetry.get('powerMetrics', {})
 
                 if device_metrics:
-                    if device_metrics.get("channelUtilization"):
-                        self.channelUtilization = packet["decoded"]["telemetry"]["deviceMetrics"]["channelUtilization"]
+                    self.deviceMetricPresent = True
+                    for key, value in device_metrics.items():
+                        if value is not None:
+                            setattr(self, f"{key}", value)
 
-                    if device_metrics.get("batteryLevel"):
-                        self.batteryLevel = packet["decoded"]["telemetry"]["deviceMetrics"]["batteryLevel"]
+                if power_metrics:
+                    self.devicePowerMetricPresent = True
+                    for key, value in power_metrics.items():
+                        if value is not None:
+                            setattr(self, f"{key}", value)
 
-                    if device_metrics.get("voltage"):
-                        self.voltage = packet["decoded"]["telemetry"]["deviceMetrics"]["voltage"]
-
-                    if device_metrics.get("airUtilTx"):
-                        self.airUtilTx = packet["decoded"]["telemetry"]["deviceMetrics"]["airUtilTx"]
-
-                    if device_metrics.get("uptimeSeconds"):
-                        self.uptimeSeconds = packet["decoded"]["telemetry"]["deviceMetrics"]["uptimeSeconds"]
 
     def add_favorite_node_attributes(self, num, longName, shortName, publicKey, lastHeard):
         self.num = num
